@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,8 +21,8 @@
 
 using namespace KAddressBookGrantlee;
 ContactGrantleePhoneObject::ContactGrantleePhoneObject(const KContacts::PhoneNumber &phone, QObject *parent)
-    : QObject(parent),
-      mPhoneNumber(phone)
+    : QObject(parent)
+    , mPhoneNumber(phone)
 {
 }
 
@@ -42,5 +42,5 @@ QString ContactGrantleePhoneObject::number() const
 
 bool ContactGrantleePhoneObject::preferred() const
 {
-    return (mPhoneNumber.type() & KContacts::PhoneNumber::Pref);
+    return mPhoneNumber.type() & KContacts::PhoneNumber::Pref;
 }
