@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class GrantleeContactUtils
 {
 public:
     GrantleeContactUtils();
-    QString variableI18n(const QString &variable);
+    Q_REQUIRED_RESULT QString variableI18n(const QString &variable);
     void insertVariableToQVariantHash(QVariantHash &contactI18n, const QString &variable);
 };
 }
